@@ -1,5 +1,6 @@
 from time import sleep
-from epics import caget, caput
+from epics import caget
+from .caput import caput
 from . import backUpVals, restoreMethods
 
 
@@ -15,7 +16,9 @@ def writeChannels(chanInfo, bak=backUpVals):
         else:
             if 'value' not in chanInfo['channels'][ch]:
                 raise RuntimeError('No value found for ' + ch)
-    kwargs = {}
+
+    discardBak = []  # caput used in this function do not need to save backUps
+    kwargs = {'bak': discardBak}
     for ch in chanInfo['channels']:
         for arg in ['wait', 'timeout']:
             kwargs[ch] = {}
@@ -40,6 +43,8 @@ def writeChannels(chanInfo, bak=backUpVals):
             for ele in bak if ele['type'] == 'group']):
         bak += [{'type': 'group', 'value': curVals, 'name': 'group'}]
 
+
+
     rampYourself = True
     if 'tramp' in chanInfo:
         oldTramps = {}
@@ -57,7 +62,7 @@ def writeChannels(chanInfo, bak=backUpVals):
                     rampYourself = rampYourself or True
             if rampYourself:
                 for ch in oldTramps:
-                    caput(ch, 0)
+                    caput(ch, 0, bak=discardBak)
                 rampSteps = 100
                 sleepTime = chanInfo['tramp'] / rampSteps
                 curVals = {}
@@ -74,7 +79,7 @@ def writeChannels(chanInfo, bak=backUpVals):
                               **kwargs[ch])
             else:
                 for ch in oldTramps:
-                    caput(ch, chanInfo['tramp'])
+                    caput(ch, chanInfo['tramp'], bak=discardBak)
         # Write final values
         for ch in chanInfo['channels']:
             caput(ch, chanInfo['channels'][ch]['value'], **kwargs[ch])
@@ -82,7 +87,7 @@ def writeChannels(chanInfo, bak=backUpVals):
             sleep(chanInfo['tramp'])
         sleep(0.1)  # Buffer time
         for ch in oldTramps:
-            caput(ch, oldTramps[ch])
+            caput(ch, oldTramps[ch], bak=discardBak)
     else:
         for ch in chanInfo['channels']:
             if 'tramp' in chanInfo['channels'][ch]:
